package com.ruoyi.bst.area.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.area.domain.Area;
import com.ruoyi.bst.area.domain.AreaQuery;
import com.ruoyi.bst.area.domain.AreaVO;
import com.ruoyi.bst.area.mapper.AreaMapper;
import com.ruoyi.bst.area.service.AreaService;
import com.ruoyi.common.utils.DateUtils;

/**
 * 运营区Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-14
 */
@Service
public class AreaServiceImpl implements AreaService
{
    @Autowired
    private AreaMapper areaMapper;

    /**
     * 查询运营区
     *
     * @param id 运营区主键
     * @return 运营区
     */
    @Override
    public AreaVO selectAreaById(Long id)
    {
        return areaMapper.selectAreaById(id);
    }

    /**
     * 查询运营区列表
     *
     * @param area 运营区
     * @return 运营区
     */
    @Override
    public List<AreaVO> selectAreaList(AreaQuery area)
    {
        return areaMapper.selectAreaList(area);
    }

    /**
     * 新增运营区
     *
     * @param area 运营区
     * @return 结果
     */
    @Override
    public int insertArea(Area area)
    {
        area.setCreateTime(DateUtils.getNowDate());
        return areaMapper.insertArea(area);
    }

    /**
     * 修改运营区
     *
     * @param area 运营区
     * @return 结果
     */
    @Override
    public int updateArea(Area area)
    {
        return areaMapper.updateArea(area);
    }

    /**
     * 批量删除运营区
     *
     * @param ids 需要删除的运营区主键
     * @return 结果
     */
    @Override
    public int deleteAreaByIds(Long[] ids)
    {
        return areaMapper.deleteAreaByIds(ids);
    }

    /**
     * 删除运营区信息
     *
     * @param id 运营区主键
     * @return 结果
     */
    @Override
    public int deleteAreaById(Long id)
    {
        return areaMapper.deleteAreaById(id);
    }
}
