package com.ruoyi.bst.areaSub.service.impl;

import java.util.Collections;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.areaSub.domain.AreaSub;
import com.ruoyi.bst.areaSub.domain.AreaSubQuery;
import com.ruoyi.bst.areaSub.domain.AreaSubVO;
import com.ruoyi.bst.areaSub.mapper.AreaSubMapper;
import com.ruoyi.bst.areaSub.service.AreaSubService;
import com.ruoyi.common.utils.DateUtils;

/**
 * 子区域Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-15
 */
@Service
public class AreaSubServiceImpl implements AreaSubService
{
    @Autowired
    private AreaSubMapper areaSubMapper;

    /**
     * 查询子区域
     *
     * @param id 子区域主键
     * @return 子区域
     */
    @Override
    public AreaSubVO selectAreaSubById(Long id)
    {
        return areaSubMapper.selectAreaSubById(id);
    }

    /**
     * 查询子区域列表
     *
     * @param areaSub 子区域
     * @return 子区域
     */
    @Override
    public List<AreaSubVO> selectAreaSubList(AreaSubQuery areaSub)
    {
        return areaSubMapper.selectAreaSubList(areaSub);
    }

    /**
     * 新增子区域
     *
     * @param areaSub 子区域
     * @return 结果
     */
    @Override
    public int insertAreaSub(AreaSub areaSub)
    {
        areaSub.setCreateTime(DateUtils.getNowDate());
        return areaSubMapper.insertAreaSub(areaSub);
    }

    /**
     * 修改子区域
     *
     * @param areaSub 子区域
     * @return 结果
     */
    @Override
    public int updateAreaSub(AreaSub areaSub)
    {
        return areaSubMapper.updateAreaSub(areaSub);
    }

    /**
     * 批量删除子区域
     *
     * @param ids 需要删除的子区域主键
     * @return 结果
     */
    @Override
    public int deleteAreaSubByIds(Long[] ids)
    {
        return areaSubMapper.deleteAreaSubByIds(ids);
    }

    /**
     * 删除子区域信息
     *
     * @param id 子区域主键
     * @return 结果
     */
    @Override
    public int deleteAreaSubById(Long id)
    {
        return areaSubMapper.deleteAreaSubById(id);
    }

    /**
     * 根据运营区ID查询子区域列表
     *
     * @param areaId 运营区ID
     * @return 子区域列表
     */
    @Override
    public List<AreaSubVO> selectAreaSubListByAreaId(Long areaId){
        if (areaId == null) {
            return Collections.emptyList();
        }
        AreaSubQuery query = new AreaSubQuery();
        query.setAreaId(areaId);
        return areaSubMapper.selectAreaSubList(query);
    }
}
