package com.ruoyi.system.user.service.impl;

import java.math.BigDecimal;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.common.core.domain.vo.UserVO;
import com.ruoyi.common.utils.MathUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.system.user.domain.UserQuery;
import com.ruoyi.system.user.service.UserDashboard;
import com.ruoyi.system.user.service.UserService;
import com.ruoyi.system.user.service.UserValidator;

/**
 * @author wjh
 * 2024/11/22
 */
@Service
public class UserValidatorImpl implements UserValidator {

    @Autowired
    private UserService userService;

    @Autowired
    private UserDashboard userDashboard;


    @Override
    public void validate(UserVO vo) {
        ServiceUtil.assertion(vo == null, "用户不存在");

        // 不允许分成大于代理商
        if (vo.getAgentId() != null) {
            ServiceUtil.assertion(MathUtils.biggerThan(vo.getPoint(), vo.getAgentPoint()), 
            "用户【%s】分成比例（%s%%)不能超过代理商分成比例（%s%%）", vo.getNickName(), vo.getPoint(), vo.getAgentPoint());
        }

        // 不允许分成小于底下的运营商
        // 查询最大分成比例
        UserQuery query = new UserQuery();
        query.setAgentId(vo.getUserId());
        BigDecimal maxOfPoint = userDashboard.selectMaxOfPoint(query);
        ServiceUtil.assertion(MathUtils.smallerThan(vo.getPoint(), maxOfPoint), 
        "用户【%s】分成比例（%s%%)不能小于底下的运营商分成比例（%s%%）", vo.getNickName(), vo.getPoint(), maxOfPoint);
    }
}

