package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.area.domain.Area;
import com.ruoyi.bst.area.domain.AreaQuery;
import com.ruoyi.bst.area.domain.AreaVO;
import com.ruoyi.bst.area.service.AreaService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 运营区Controller
 *
 * @author ruoyi
 * @date 2025-03-14
 */
@RestController
@RequestMapping("/bst/area")
public class AreaController extends BaseController
{
    @Autowired
    private AreaService areaService;

    /**
     * 查询运营区列表
     */
    @PreAuthorize("@ss.hasPermi('bst:area:list')")
    @GetMapping("/list")
    public TableDataInfo list(AreaQuery query)
    {
        startPage();
        startOrderBy();
        List<AreaVO> list = areaService.selectAreaList(query);
        return getDataTable(list);
    }

    /**
     * 导出运营区列表
     */
    @PreAuthorize("@ss.hasPermi('bst:area:export')")
    @Log(title = "运营区", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AreaQuery query)
    {
        List<AreaVO> list = areaService.selectAreaList(query);
        ExcelUtil<AreaVO> util = new ExcelUtil<AreaVO>(AreaVO.class);
        util.exportExcel(response, list, "运营区数据");
    }

    /**
     * 获取运营区详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:area:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(areaService.selectAreaById(id));
    }

    /**
     * 新增运营区
     */
    @PreAuthorize("@ss.hasPermi('bst:area:add')")
    @Log(title = "运营区", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Area area)
    {
        return toAjax(areaService.insertArea(area));
    }

    /**
     * 修改运营区
     */
    @PreAuthorize("@ss.hasPermi('bst:area:edit')")
    @Log(title = "运营区", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Area area)
    {
        return toAjax(areaService.updateArea(area));
    }

    /**
     * 删除运营区
     */
    @PreAuthorize("@ss.hasPermi('bst:area:remove')")
    @Log(title = "运营区", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(areaService.deleteAreaByIds(ids));
    }
}
